# ZeroROS
Python-only, dependency-free middleware that resembles ROS using ZeroMQ.

This library is intended to be used for small projects that require a simple middleware
for communication between processes. It is not intended to be a replacement for ROS.

## Installation
Use pip to install the library:

```bash
pip install zeroros
```

## Usage
The library is composed of three main classes: `Publisher`,  `Subscriber` and 
`MessageBroker`.

### MessageBroker
The `MessageBroker` class is used to create a message broker that can be used by
publishers and subscribers to communicate with each other.

```python
from zeroros import MessageBroker

broker = MessageBroker()
```

### Publisher
The `Publisher` class is used to publish messages to a topic. The constructor takes two
arguments: the topic name and the message type. The topic name is a string, while the
message type is a Python class. The message type is used to serialize and deserialize
messages.

```python
from zeroros import Publisher

pub = Publisher("topic_name", String)
pub.publish("Hello world!")
```

### Subscriber
The `Subscriber` class is used to subscribe to a topic and receive messages. The constructor
takes two arguments: the topic name and the message type. The topic name is a string, while
the message type is a Python class. The message type is used to serialize and deserialize
messages.

```python
import time
from zeroros import Subscriber

def callback(msg):
    print(msg)

sub = Subscriber("topic_name", String, callback)
while True:
    # Do something else
    time.sleep(1)

# Stop the subscriber
sub.stop()
```

### Messages
The library comes with a few built-in messages that can be used out of the box. The
following messages are available:

* `std_msgs.String`
* `std_msgs.Int`
* `std_msgs.Float`
* `std_msgs.Bool`
* `std_msgs.Header`
* `geometry_msgs.Vector3`
* `geometry_msgs.Vector3Stamped`
* `geometry_msgs.Twist`
* `geometry_msgs.Quaternion`
* `geometry_msgs.Pose`
* `geometry_msgs.PoseStamped`
* `geometry_msgs.PoseWithCovariance`
* `geometry_msgs.TwistWithCovariance`
* `nav_msgs.Odometry`
* `nav_msgs.Path`
* `sensors_msgs.LaserScan`
* More to come...